package com.chinaitop.depot.fumigation.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.fumigation.model.*;
import com.chinaitop.depot.fumigation.service.FumigationForRecordService;
import com.chinaitop.depot.fumigation.service.FumigationPlanService;
import com.chinaitop.depot.fumigation.service.PesticidePlanService;
import com.chinaitop.depot.utils.HttpUtil;
import com.chinaitop.depot.utils.JsonToObjectUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @author lvzhikai
 * @description: 熏蒸作业记录
 * @create 2019-1-14 10:57
 */
@RestController
@RequestMapping(value = "/storage/fumigationFroRecord")
@Api(value = "FumigationFroRecordController", description = "熏蒸备注类")
@SuppressWarnings("all")
public class FumigationForRecordController {

    @Resource
    private FumigationForRecordService fumigationFroRecordService;

    @Resource
    private FumigationPlanService fumigationPlanService;

    @Resource
    private PesticidePlanService pesticidePlanService;

    // 获取ip地址
    @Value("${reportUrl}")
    private String reportPath;
    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationForRecordList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸备案列表", notes = "熏蒸备案列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "申请开始时间", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "申请结束时间", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query")
    })
    public PageInfo<Map<String,Object>> getFumigationForRecordList(Integer pageNum, Integer pageSize, String searchStartDate, String searchEndDate, Integer houseId, Integer orgId) throws Exception {
        Map<String,Object> map = new HashMap<>();
        List<Map<String,Object>> list = null;

        if (ParameterUtil.isnotnull(orgId))//粮库查询
            map.put("orgId",orgId);

        if (ParameterUtil.isnotnull(searchStartDate))
            map.put("searchStartDate",searchStartDate);

        if (ParameterUtil.isnotnull(searchEndDate))
            map.put("searchEndDate",searchEndDate);

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        list = fumigationFroRecordService.getFumigationFroRecordList(map);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<Map<String,Object>>(list);
        if(list.size() > 0){
            pageInfo.setStartRow(pageInfo.getStartRow()+1);
            pageInfo.setEndRow(pageInfo.getEndRow()+1);
            pageInfo.setPageNum(pageNum);
            pageInfo.setPageSize(pageSize);
        }
        return pageInfo;
    }

    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationPlanList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸列表", notes = "熏蒸信息列表(新增作业过程、作业过程时用)，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房Id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query"),
            @ApiImplicitParam(name = "queryType", value = "查询状态", paramType = "query")
    })
    public PageInfo<TFumigationForrecord> getFumigationPlanList(Integer pageNum, Integer pageSize, Integer houseId, String createTime, Integer orgId, String queryType) {
        TFumigationForrecordExample example = new TFumigationForrecordExample();
        TFumigationForrecordExample.Criteria criteria = example.createCriteria();

        Map<String,Object> map = new HashMap<>();

        if (ParameterUtil.isnotnull(houseId)) {//仓房查询
            criteria.andHouseIdEqualTo(houseId);
        }

        if (ParameterUtil.isnotnull(createTime)) {//归档用
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            criteria.andCreateTimeLessThanOrEqualTo(date);
        }

        if (ParameterUtil.isnotnull(orgId)) {//粮库查询
            criteria.andOrgIdEqualTo(orgId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        //施药数据。过程数据。善后数据。备案数据
        if(ParameterUtil.isequal(queryType,"XZ") || ParameterUtil.isequal(queryType,"GC")){
            criteria.andStateEqualTo(8);
        }else if(ParameterUtil.isequal(queryType,"SH")){
            criteria.andStateEqualTo(9);
        }else if(ParameterUtil.isequal(queryType,"BA")){
            criteria.andStateEqualTo(5);
        }

        criteria.andDeleteStateEqualTo("1");

        List<TFumigationForrecord> list = fumigationFroRecordService.getList(example);
        PageInfo<TFumigationForrecord> pageInfo = new PageInfo<TFumigationForrecord>(list);
        return pageInfo;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getFroRecordDeatil", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id集合查询熏蒸备案数据", notes = "根据熏蒸备案id集合查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getFroRecordDeatil(String planIds) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        if (planIds != null) {
            String storehouseNames = "";
            Map<String, Object> map = new HashMap<String, Object>();
            map.put("planIds",planIds.split(","));
            List<Map<String, Object>> forRecordList = fumigationFroRecordService.getFumigationDateByIds(map);
            for (Map<String, Object> forRecord:forRecordList) {
                storehouseNames += forRecord.get("storehouse_name") + ",";
            }
            modelMap.put("fumigationEdit",ParameterUtil.slashCapitals(forRecordList));//熏蒸数据
            modelMap.put("storehouseNames",storehouseNames.substring(0,storehouseNames.length()-1));//仓房名称集合--熏蒸作业地点
        }

        return modelMap;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getFroRecordById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id查询熏蒸备案数据", notes = "根据熏蒸备案id查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecordId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getFroRecordById(String forRecordId){
        Map<String, Object> modelMap = new HashMap<String, Object>();

        if (forRecordId != null) {
            String planIds="";
            //获取备案数据
            List<Map<String, Object>> forRecordData = fumigationFroRecordService.getFroRecordById(forRecordId);
            for (Map<String, Object> maps:forRecordData) {
                planIds+=maps.get("planids")+",";
            }
            planIds = planIds.substring(0,planIds.length()-1);
            forRecordData.get(0).remove("planids");
            forRecordData.get(0).put("planIds",planIds);
            modelMap.put("forRecordData",ParameterUtil.slashCapitals(forRecordData));//熏蒸备案数据

            //下边获取熏蒸数据
            String storehouseNames = "";
            Map<String, Object> map = new HashMap<String, Object>();
            map.put("planIds",planIds.split(","));
            List<Map<String, Object>> forRecordList = fumigationFroRecordService.getFumigationDateByIds(map);
            for (Map<String, Object> forRecord:forRecordList) {
                storehouseNames += forRecord.get("storehouse_name") + ",";
            }
            modelMap.put("fumigationEdit",ParameterUtil.slashCapitals(forRecordList));//熏蒸数据

            TFumigationPersonnelExample tFumigationPersonnelExample = new TFumigationPersonnelExample();
            TFumigationPersonnelExample.Criteria criteria = tFumigationPersonnelExample.createCriteria();
            criteria.andForrecordIdEqualTo(forRecordId);
            List<TFumigationPersonnel> personnelList= fumigationFroRecordService.getPersonnelData(tFumigationPersonnelExample);
            modelMap.put("personnelList",personnelList);//熏蒸数据
            modelMap.put("storehouseNames",storehouseNames.substring(0,storehouseNames.length()-1));//仓房名称集合--熏蒸作业地点
        }

        return modelMap;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id查询熏蒸备案数据", notes = "根据熏蒸备案id查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecordId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getInfo(String forRecordId){
        Map<String, Object> modelMap = new HashMap<String, Object>();

        if (forRecordId != null) {
            TFumigationForrecord tFumigationForrecord = fumigationFroRecordService.getById(forRecordId);
            modelMap.put("record",tFumigationForrecord);
            Map<String, Object> pesticide = fumigationFroRecordService.findYjxxById(forRecordId);
            if(pesticide!=null){
                modelMap.put("drugName",pesticide.get("drugname"));//获取药剂名称
                modelMap.put("reagentType",pesticide.get("reagenttype"));//获取药剂剂型名称
            }

        }

        return modelMap;
    }

    /**
     * 保存熏蒸备案信息
     * @param fumigation
     * @return
     */
    @RequestMapping(value="/saveFumigationForRecordDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸备案信息", notes = "保存熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "备案备案数据", paramType = "form"),
            @ApiImplicitParam(name = "addedDetail", value = "备案熏蒸人数集合", paramType = "form"),
            @ApiImplicitParam(name = "fumigation", value = "熏蒸数据集合", paramType = "form"),
            @ApiImplicitParam(name = "stateType", value = "保存状态，是提交还是保存", paramType = "form")

    })
    public Map<String, Object> saveFumigationForRecordDate(String forRecord, String addedDetail,String fumigation,String stateType) throws Exception {
        if(ParameterUtil.isequal(stateType,"getSubmit")){
            stateType = "7";
        }else{
            stateType = "6";
        }

        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        String uuid = ParameterUtil.getCode();
        TFumigationForrecord tFumigationForrecord = (TFumigationForrecord) JsonToObjectUtils.jsonToObject(forRecord,"com.chinaitop.depot.fumigation.model.TFumigationForrecord");
        if (tFumigationForrecord.getId() == null) {
            //新增熏蒸备案数据
            tFumigationForrecord.setDeleteState("1");//默认设置删除标志
            tFumigationForrecord.setCreateTime(new Date());//创建时间
            tFumigationForrecord.setId(uuid);
            fumigationFroRecordService.add(tFumigationForrecord);
        } else {
            uuid = tFumigationForrecord.getId();
            tFumigationForrecord.setUpdatetime(new Date());//修改时间
            fumigationFroRecordService.update(tFumigationForrecord);
        }

        //熏蒸人员字段
        String[] personnelDates = addedDetail.split("},");
        for (String personnel:personnelDates) {
            TFumigationPersonnel tFumigationPersonnel = (TFumigationPersonnel) JsonToObjectUtils.jsonToObject(personnel + "}", "com.chinaitop.depot.fumigation.model.TFumigationPersonnel");
            if (tFumigationPersonnel.getId() == null) {
                tFumigationPersonnel.setDeleteState("1");//默认设置删除标志
                tFumigationPersonnel.setCreateTime(new Date());//创建时间
                tFumigationPersonnel.setId(ParameterUtil.getCode());
                tFumigationPersonnel.setForrecordId(uuid);
                tFumigationPersonnel.setOrgId(tFumigationForrecord.getOrgId());
                fumigationFroRecordService.addPersonnel(tFumigationPersonnel);
            } else {
                tFumigationPersonnel.setUpdatetime(new Date());//修改时间
                fumigationFroRecordService.updatePersonnel(tFumigationPersonnel);
            }
        }

        //熏蒸信息字段
        String[] fumigationDates = fumigation.split("},");
        Integer c=1;
        for (String fumigations:fumigationDates) {
            JSONObject fumMap = null;
            if(c != fumigationDates.length){
                fumMap = JSON.parseObject(fumigations+"}");
            }else{
                fumMap = JSON.parseObject(fumigations);
            }
            c++;
            //修改熏蒸状态
            TFumigationPlanExample example = new TFumigationPlanExample();
            TFumigationPlanExample.Criteria criteria = example.createCriteria();
            criteria.andIdEqualTo(fumMap.get("planid").toString());

            TFumigationPlan tFumigationPlan = new TFumigationPlan();
            tFumigationPlan.setState(Integer.parseInt(stateType));
            tFumigationPlan.setGrainMoisture(fumMap.get("grainMoisture").toString());
            tFumigationPlan.setStowWay(fumMap.get("stowWay").toString());
            tFumigationPlan.setForRecordId(uuid);
            fumigationPlanService.updateByExample(tFumigationPlan, example);

            //修改熏蒸施药状态
            TFumigationPesticideExample pesticideExample = new TFumigationPesticideExample();
            TFumigationPesticideExample.Criteria pesticideCriteria = pesticideExample.createCriteria();
            pesticideCriteria.andIdEqualTo(fumMap.get("pesticideid").toString());

            TFumigationPesticide tFumigationPesticide = new TFumigationPesticide();
            tFumigationPesticide.setReagentType("3024");
            tFumigationPesticide.setValidity(fumMap.get("validity").toString());
            tFumigationPesticide.setGetNumber(fumMap.get("getNumber").toString());
            tFumigationPesticide.setGetPerson(fumMap.get("getPerson").toString());
            tFumigationPesticide.setGetTime(ParameterUtil.string2datetime(fumMap.get("getTime").toString()));
            pesticidePlanService.updateByExample(tFumigationPesticide, pesticideExample);
        }

        if(ParameterUtil.isequal(stateType,"7")){
            try {
                //如果是提交的话则除了保存还要把数据提交到市级来进行审批
                Map<String, Object> dataMap = fumigationFroRecordService.getFroRecordByIds(uuid);
                String url = reportPath+"/api/cbl-app/cbl/fumigation/insertFumigation";//市级接口
                String strResult = HttpUtil.doPost(url,JSON.toJSONString(dataMap));
            }catch (IOException e) {
                e.printStackTrace();
            } finally {
                modelMap.put("status", "success");
            }
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 删除熏蒸申请信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeDetail", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除熏蒸备案信息", notes = "删除熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "熏蒸主键集合", paramType = "form"),
            @ApiImplicitParam(name = "forrecordId", value = "主键id", paramType = "form")
    })
    public Map<String, Object> removeDetail(String planIds, String forrecordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        /*if (planIds != null) {
            String[] planId = planIds.split(",");
            for (String id:planId) {
                //修改熏蒸状态
                TFumigationPlanExample example = new TFumigationPlanExample();
                TFumigationPlanExample.Criteria criteria = example.createCriteria();
                criteria.andIdEqualTo(id);

                TFumigationPlan tFumigationPlan = new TFumigationPlan();
                tFumigationPlan.setState(5);
                tFumigationPlan.setForRecordId("");
                fumigationPlanService.updateByExample(tFumigationPlan, example);
            }
        }*/
        //修改熏蒸状态
        TFumigationForrecordExample tFumigationForrecordExample = new TFumigationForrecordExample();
        TFumigationForrecordExample.Criteria criteria = tFumigationForrecordExample.createCriteria();
        criteria.andIdEqualTo(forrecordId);

        TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
        tFumigationForrecord.setDeleteState("0");
        fumigationFroRecordService.updateByExample(tFumigationForrecord, tFumigationForrecordExample);
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 提交熏蒸申请信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getSubmit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="提交熏蒸备案信息", notes = "提交熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "熏蒸主键集合", paramType = "form"),
            @ApiImplicitParam(name = "forrecordId", value = "主键id", paramType = "form")
    })
    public Map<String, Object> getSubmit(String planIds, String forrecordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        if (planIds != null) {
            String[] planId = planIds.split(",");
            for (String id:planId) {
                //修改熏蒸状态
                TFumigationPlanExample example = new TFumigationPlanExample();
                TFumigationPlanExample.Criteria criteria = example.createCriteria();
                criteria.andIdEqualTo(id);

                TFumigationPlan tFumigationPlan = new TFumigationPlan();
                tFumigationPlan.setState(7);
                fumigationPlanService.updateByExample(tFumigationPlan, example);
            }
        }
        try {
            //如果是提交的话则除了保存还要把数据提交到市级来进行审批
            Map<String, Object> dataMap = fumigationFroRecordService.getFroRecordByIds(forrecordId);
            String url = reportPath+"/api/cbl-app/cbl/fumigation/insertFumigation";//市级接口
            String strResult = HttpUtil.doPost(url,JSON.toJSONString(dataMap));
        }catch (IOException e) {
            e.printStackTrace();
        } finally {
            modelMap.put("status", "success");
        }
        return modelMap;
    }

    /**
     * 提交熏蒸审批信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getForRecordApproval", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="提交熏蒸备案信息", notes = "提交熏蒸备案信息-市级用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "主键id", paramType = "form")
    })
    public void getForRecordApproval(String forRecord) throws Exception {
        //市级传输过来的审批过后的备案数据
        JSONObject forRecordData = JSONObject.parseObject(forRecord);
        String forrecordId = forRecordData.get("forrecordId").toString();
        Map<String, Object> modelMap = new HashMap<>();
        if (forrecordId != null) {
            //修改熏蒸备案信息
            TFumigationForrecordExample tFumigationForrecordExample = new TFumigationForrecordExample();
            TFumigationForrecordExample.Criteria criteria = tFumigationForrecordExample.createCriteria();
            criteria.andIdEqualTo(forrecordId);

            TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
            tFumigationForrecord.setOrgansOpinion(forRecordData.get("organsOpinion").toString());
            tFumigationForrecord.setOutPerson(forRecordData.get("outPerson").toString());
            tFumigationForrecord.setOutForrecordTime(ParameterUtil.string2datetime(forRecordData.get("outForrecordTime").toString()));
            fumigationFroRecordService.updateByExample(tFumigationForrecord, tFumigationForrecordExample);

            //获取备案数据
            List<Map<String, Object>> forRecords = fumigationFroRecordService.getFroRecordById(forrecordId);
            String planIds = "";
            for (Map<String, Object> maps:forRecords) {
                planIds+=maps.get("planids")+",";
            }
            planIds = planIds.substring(0,planIds.length()-1);

            //下边获取熏蒸数据
            String[] planId = planIds.split(",");
            for (String id:planId) {
                //修改熏蒸状态
                TFumigationPlanExample example = new TFumigationPlanExample();
                TFumigationPlanExample.Criteria planCriteria = example.createCriteria();
                planCriteria.andIdEqualTo(id);

                TFumigationPlan tFumigationPlan = new TFumigationPlan();
                tFumigationPlan.setState(8);
                fumigationPlanService.updateByExample(tFumigationPlan, example);
            }
        }
    }

    /**
     * 保存熏蒸备案信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/insertRecord", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸信息及备案信息", notes = "保存熏蒸信息及备案信息-市级用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "熏蒸备案基础信息和备案信息", paramType = "form")
    })
    public void insertRecord(String forRecord) throws Exception {
        JSONObject recordInfo = JSONObject.parseObject(forRecord);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String xzzydh = (String)recordInfo.get("id");
        String operationSupervisor = (String)recordInfo.get("operationSupervisor;");
        String contactPhone = (String)recordInfo.get("contactPhone");
        String xzzydd=(String)recordInfo.get("operationLocaltion");
        String lyccdwfzr = (String)recordInfo.get("orgPerson");
        String lyccdw = (String)recordInfo.get("orgName");
        String ylccdwlxdh = (String)recordInfo.get("orgPhone");
        String fumigationStart=(String)recordInfo.get("fumigationStart");
        String fumigationEnd = (String)recordInfo.get("fumigationEnd");
        String creater = (String)recordInfo.get("creater");
        String createTime = (String)recordInfo.get("createTime");
        String updateTime = (String)recordInfo.get("updateTime");
        String enterpriseOpinion = (String)recordInfo.get("qyspyj");
        String organsOpinion = (String)recordInfo.get("qlbspyj");
        String spsj = (String)recordInfo.get("qlbspsj");
        String spr =(String)recordInfo.get("qyfzr");
        List<Map<String,Object>> details = ( List<Map<String,Object>>)recordInfo.get("detailVOS");
        for (Map<String, Object> detail : details) {
            TFumigationForrecord fumigationForrecord = new TFumigationForrecord();
            String uuid = ParameterUtil.getCode();
            fumigationForrecord.setId(uuid);
            fumigationForrecord.setXzzydh(xzzydh);
            fumigationForrecord.setOperationSupervisor(operationSupervisor);
            fumigationForrecord.setContactPhone(contactPhone);
            fumigationForrecord.setXzzydd(xzzydd);
            fumigationForrecord.setLyccdwfzr(lyccdwfzr);
            fumigationForrecord.setLyccdw(lyccdw);
            fumigationForrecord.setYlccdwlxdh(ylccdwlxdh);
            fumigationForrecord.setFumigationStart(format.parse(fumigationStart));
            fumigationForrecord.setFumigationEnd(format.parse(fumigationEnd));
            fumigationForrecord.setSqr(creater);
            fumigationForrecord.setCreateTime(format.parse(createTime));
            fumigationForrecord.setUpdatetime(format.parse(updateTime));
            fumigationForrecord.setEnterpriseOpinion(enterpriseOpinion);
            fumigationForrecord.setOrgansOpinion(organsOpinion);
            fumigationForrecord.setSpsj(format.parse(spsj));
            fumigationForrecord.setSpr(spr);

            String cfdm = (String)detail.get("cfbh");
            Map<String,Integer> info = fumigationFroRecordService.getByCfdm(cfdm);
            Integer orgId = info.get("orgId");
            Integer houseId = info.get("houseId");
            String cfmc = (String)detail.get("cfmc");
            BigDecimal lssl = new BigDecimal(ObjectUtils.toString(detail.get("kcsl")));
            String lspz = (String)detail.get("lspz");
            String lyxz = (String)detail.get("lsxz");
            String cgxzfs = (String)detail.get("convFumigation");
            String hlxzfs = (String)detail.get("recFumigation");
            Integer xzfs = (Integer)recordInfo.get("xzfs");
            String hlxzynhljsjh = (String)detail.get("recIcCombine");
            String yjmc = (String)detail.get("drugCode");
            String jx = (String)detail.get("drugType");
            BigDecimal nd = new BigDecimal(ObjectUtils.toString(detail.get("drugConcentration")));;
            String syff = (String)detail.get("applicationMethod");
            Integer lqsl = (Integer)detail.get("getNumber");
            BigDecimal lddwyyl = new BigDecimal(ObjectUtils.toString(detail.get("grainDosage")));
            BigDecimal kjdwyyl = new BigDecimal(ObjectUtils.toString(detail.get("spaceDosage")));
            BigDecimal zyyl = new BigDecimal(ObjectUtils.toString(detail.get("totalDosage")));
            String hcjcdh = (String)detail.get("pestNo");
            List<Map<String,Object>> pest =  (List<Map<String,Object>>)detail.get("pestVOS");
            if(!CollectionUtils.isEmpty(pest)){
                String zyhc = "";
                String ckmd = "";
                for (Map<String, Object> stringObjectMap : pest) {
                    if(stringObjectMap.get("pestType") !=null){
                        zyhc +=(String)stringObjectMap.get("pestType")+"#";
                    }
                    if(stringObjectMap.get("density") !=null){
                        ckmd += (String)stringObjectMap.get("density") + "|";
                    }
                }
                zyhc = zyhc.substring(0,zyhc.lastIndexOf("#"));
                ckmd = ckmd.substring(0,ckmd.lastIndexOf("|"));
                fumigationForrecord.setZyhc(zyhc);
                fumigationForrecord.setCkmd(ckmd);
            }
            fumigationForrecord.setCfdm(cfdm);
            fumigationForrecord.setCfmc(cfmc);
            fumigationForrecord.setHouseId(houseId);
            fumigationForrecord.setOrgId(orgId);
            fumigationForrecord.setLssl(lssl);
            fumigationForrecord.setLspz(lspz);
            fumigationForrecord.setLyxz(lyxz);
            fumigationForrecord.setCgxzfs(cgxzfs);
            fumigationForrecord.setHlxzfs(hlxzfs);
            fumigationForrecord.setXzfs(xzfs);
            fumigationForrecord.setHlxzynhljsjh(hlxzynhljsjh);
            fumigationForrecord.setYjmc(yjmc);
            fumigationForrecord.setJx(jx);
            fumigationForrecord.setNd(nd);
            fumigationForrecord.setSyff(syff);
            fumigationForrecord.setLqsl(new BigDecimal(lqsl));
            fumigationForrecord.setLddwyyl(lddwyyl);
            fumigationForrecord.setKjdwyyl(kjdwyyl);
            fumigationForrecord.setZyyl(zyyl);
            fumigationForrecord.setHcjcdh(hcjcdh);
            fumigationForrecord.setState(8);
            fumigationFroRecordService.add(fumigationForrecord);
        }

        //市级传输过来的审批过后的备案数据
        /*Map<String, Object> modelMap = new HashMap<>();*/
        // JSON字符串转对象
       /* ObjectMapper mapper = new ObjectMapper();
        JavaType javaType = mapper.getTypeFactory().constructParametricType(ArrayList.class,TFumigationForrecord.class);
        List<TFumigationForrecord> tFumigationForrecordList = mapper.readValue(forRecord, javaType);*/
        /*if(!CollectionUtils.isEmpty(tFumigationForrecordList)){
            for (TFumigationForrecord tFumigationForrecord : tFumigationForrecordList) {
                String uuid = ParameterUtil.getCode();
                tFumigationForrecord.setId(uuid);
                tFumigationForrecord.setState(8);
                tFumigationForrecord.setCreateTime(new Date());
                fumigationFroRecordService.add(tFumigationForrecord);
                if(CollectionUtils.isEmpty(tFumigationForrecord.getFumigationPersonnelList())){
                    for (TFumigationPersonnel tFumigationPersonne : tFumigationForrecord.getFumigationPersonnelList()) {
                        tFumigationPersonne.setDeleteState("1");//默认设置删除标志
                        tFumigationPersonne.setCreateTime(new Date());//创建时间
                        tFumigationPersonne.setId(ParameterUtil.getCode());
                        tFumigationPersonne.setForrecordId(uuid);
                        tFumigationPersonne.setOrgId(tFumigationForrecord.getOrgId());
                        fumigationFroRecordService.addPersonnel(tFumigationPersonne);
                    }

                }
            }
        }*/

    }
}