package com.chinaitop.depot.product.service.impl;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.chinaitop.depot.feign.BasicFeignClient;
import com.chinaitop.depot.product.mapper.StorageProductFcbgzMapper;
import com.chinaitop.depot.product.mapper.StorageProductKcslMapper;
import com.chinaitop.depot.product.model.StorageProductFcbgz;
import com.chinaitop.depot.product.model.StorageProductKcsl;
import com.chinaitop.depot.product.model.StorageProductKcslExample;
import com.chinaitop.depot.product.service.StorageProductKcslService;

@Service
public class StorageProductKcslServiceImpl implements StorageProductKcslService {

	@Resource
	private StorageProductKcslMapper storageProductKcslMapper;

	@Resource
    private StorageProductFcbgzMapper storageProductFcbgzMapper;

	@Resource
	private BasicFeignClient basicWarehouseFeignClient;

	private final static String CRK_STATUS_KC = "1"; //出入库状态：空仓状态

	private final static String CRK_STATUS_RK = "2"; //出入库状态：入库状态
	
	private final static String CRK_STATUS_CK = "4"; //出入库状态：出库状态

	@Override
	public StorageProductKcsl findByObj(StorageProductFcbgz fcbgz) throws Exception {
		List<StorageProductKcsl> list = null;
		StorageProductKcsl StorageProductKcsl = null;
		StorageProductKcslExample example = new StorageProductKcslExample();
		StorageProductKcslExample.Criteria criteria = example.createCriteria();
		if (StringUtils.isNotBlank(fcbgz.getHouseId())) {
			criteria.andHouseIdEqualTo(Integer.parseInt(fcbgz.getHouseId()));
		}
		if (StringUtils.isNotBlank(fcbgz.getWarehouseId())) {
			criteria.andWarehouseIdEqualTo(Integer.parseInt(fcbgz.getWarehouseId()));
		}
		if (StringUtils.isNotBlank(fcbgz.getLspz())) {
			criteria.andLypzEqualTo(Integer.parseInt(fcbgz.getLspz()));
		}
		if (StringUtils.isNotBlank(fcbgz.getNature())) {
			criteria.andLyxzEqualTo(Integer.parseInt(fcbgz.getNature()));
		}
		if (StringUtils.isNotBlank(fcbgz.getLevels())) {
			criteria.andLydjEqualTo(Integer.parseInt(fcbgz.getLevels()));
		}
		if (null != fcbgz.getOrgId()) {
			criteria.andOrgIdEqualTo(fcbgz.getOrgId());
		}
		example.setOrderByClause(" input_time desc");
		list = storageProductKcslMapper.selectByExample(example);
		boolean empty = list.isEmpty();
		if (!empty) {
			StorageProductKcsl = list.get(0);
		}
		return StorageProductKcsl;
	}

	@Override
	public void add(HttpServletRequest request, StorageProductKcsl kcsl) throws Exception {
		String orgId = request.getSession().getAttribute("orgId")+"";
		String uuid = UUID.randomUUID().toString().replace("-", "");
		Date date = new Date();
		kcsl.setId(uuid);
		kcsl.setOrgId(Integer.parseInt(orgId));
		kcsl.setInputTime(date);
		kcsl.setHdsj(date);
		storageProductKcslMapper.insertSelective(kcsl);
	}

	@Override
	public void remove(Integer houseId, Integer wareId, Integer orgId) throws Exception {
		StorageProductKcslExample example = new StorageProductKcslExample();
		StorageProductKcslExample.Criteria criteria = example.createCriteria();
		if (null != houseId) {
			criteria.andHouseIdEqualTo(houseId);
		}
		if (null != wareId) {
			criteria.andWarehouseIdEqualTo(wareId);
		}
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}
		storageProductKcslMapper.deleteByExample(example);
	}

	@Override
	public List<StorageProductKcsl> getList(Integer houseId, Integer wareId, Integer orgId) throws Exception {
		List<StorageProductKcsl> list = null;
		StorageProductKcslExample example = new StorageProductKcslExample();
		StorageProductKcslExample.Criteria criteria = example.createCriteria();
		if (null != houseId) {
			criteria.andHouseIdEqualTo(houseId);
		}
		if (null != wareId) {
			criteria.andWarehouseIdEqualTo(wareId);
		}
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}
		example.setOrderByClause(" house_id");
		list = storageProductKcslMapper.selectByExample(example);
		return list;
	}

	@Override
	public Map<String, String> update(HttpServletRequest request, StorageProductFcbgz fcbgz, Map<String, String> map) throws Exception {
		StorageProductKcsl kcsl = findByObj(fcbgz);
		BigDecimal kcs = new BigDecimal(0);
		String crk_bz = ""; //0出库，1入库
		if (null != kcsl) {
			kcs = kcsl.getKcsl();

			//入库
			if (StringUtils.isNotBlank(fcbgz.getStorageQuantity()) && !"0".equals(fcbgz.getStorageQuantity())) {
				BigDecimal rksl = new BigDecimal(fcbgz.getStorageQuantity());
				kcs = kcs.add(rksl).setScale(3, BigDecimal.ROUND_DOWN);
				crk_bz = CRK_STATUS_RK;
			}
			//出库
			if (StringUtils.isNotBlank(fcbgz.getOutboundQuantity()) && !"0".equals(fcbgz.getOutboundQuantity())) {
				BigDecimal cksl = new BigDecimal(fcbgz.getOutboundQuantity());
				kcs = kcs.subtract(cksl).setScale(3, BigDecimal.ROUND_DOWN);
				crk_bz = CRK_STATUS_CK;
			}
			/**
			 * 重新赋值库存数量，情况分两种
			 * 1、kcs如果成0了，那么删除了数据
			 * 2、kcs不等于0，修改库存数据的库存数量
			 */
			BigDecimal k = new BigDecimal(0);
			if (k.compareTo(kcs) == -1 || k.compareTo(kcs) == 1) {
				kcsl.setKcsl(kcs);
				storageProductKcslMapper.updateByPrimaryKey(kcsl);
			} else {
				crk_bz = CRK_STATUS_KC;
				storageProductKcslMapper.deleteByPrimaryKey(kcsl.getId());
			}

			map.put("status","success");
		} else {
			//如果没有对应的库存数据，那就新增一条
			kcsl = new StorageProductKcsl();
			kcsl.setHouseId(Integer.parseInt(fcbgz.getHouseId()));
			if ("2".equals(fcbgz.getStorage())) {//油罐的话，仓房和货位是同一个值
				kcsl.setWarehouseId(Integer.parseInt(fcbgz.getHouseId()));
			} else if ("1".equals(fcbgz.getStorage())) {
				kcsl.setWarehouseId(Integer.parseInt(fcbgz.getWarehouseId()));
			}
			kcsl.setLypz(Integer.parseInt(fcbgz.getLspz()));
			kcsl.setLyxz(Integer.parseInt(fcbgz.getNature()));
			kcsl.setLydj(Integer.parseInt(fcbgz.getLevels()));
			Integer cd = fcbgz.getPlaces() == null ? null : Integer.parseInt(fcbgz.getPlaces());
			kcsl.setLycd(cd);
			kcsl.setRksj(fcbgz.getRecordDate());
			kcsl.setScrq(fcbgz.getProductionDate());
			//入库
			if (StringUtils.isNotBlank(fcbgz.getStorageQuantity()) && !"0".equals(fcbgz.getStorageQuantity())) {
				BigDecimal rksl = new BigDecimal(fcbgz.getStorageQuantity());
				kcsl.setKcsl(rksl.setScale(3, BigDecimal.ROUND_DOWN));
				crk_bz = CRK_STATUS_RK;
				add(request, kcsl);
				map.put("status","success");
			} else {
				map.put("status","error");
				map.put("msg", "出库前请先入库");
			}
		}
		
		/* -----------------修改出入库状态和粮情卡状态---------------------start */
		//先修改出入库状态
		updateCrkZt(crk_bz, fcbgz.getOrgId(), kcsl.getWarehouseId(), fcbgz.getStorage());
		//然后检查对应仓房的粮情卡是否需要归档
		updateLqkStatus(crk_bz, fcbgz.getOrgId(), Integer.parseInt(fcbgz.getHouseId()), 
				kcsl.getWarehouseId(), fcbgz.getStorage());
		/* -----------------修改出入库状态---------------------end */
		return map;
	}

	/**
	 * 修改成品粮库的出入库状态
	 * @param crk_bz 出入库状态值
	 * @param orgId 单位ID
	 * @param warehouseId 货位ID
	 * @param ywlx 1分件(粮仓),2油罐
	 */
	private void updateCrkZt(String crk_bz, Integer orgId, Integer warehouseId, String ywlx) {
		List<Map<String, Object>> wareList = new ArrayList<>();
		Map<String, Object> wareMap = new HashMap<>();
		wareMap.put("wareId", warehouseId); // 货位id
		wareMap.put("orgId", orgId); // 组织机构id
		wareMap.put("crk_status", crk_bz);
		wareMap.put("ywlx", ywlx);
		wareMap.put("lylx", "1");//这里的默认都是成品粮
		wareList.add(wareMap);
		String wareJson = JSON.toJSONString(wareList);
		basicWarehouseFeignClient.updateWarehouseCrkStatus(wareJson);
	}

	/**
	 * 修改成品粮粮情卡归档状态
	 * @param crk_bz
	 * @param orgId
	 * @param houseId
	 * @param warehouseId
	 * @param ywlx
	 */
	private void updateLqkStatus(String crk_bz, Integer orgId, Integer houseId, Integer warehouseId, String ywlx) {
		if (crk_bz.equals(CRK_STATUS_KC) || crk_bz.equals(CRK_STATUS_CK)) {
			Map<String, Object> param = new HashMap<>();
			param.put("orgId", orgId);
			param.put("houseId", houseId);
			if ("1".equals(ywlx)) {
				param.put("wareId", warehouseId);
			}
			List<Map<String, Object>> list = storageProductFcbgzMapper.findLqkdata(param);
			if (null != list && list.size() > 0) {
				Map<String, Object> result = list.get(0);
				storageProductFcbgzMapper.updateLqkStatus(result);
			}
		}
	}

	@Override
	public void restHdData(Integer orgId) throws Exception {
		StorageProductKcslExample example = new StorageProductKcslExample();
		StorageProductKcslExample.Criteria criteria = example.createCriteria();
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
			StorageProductKcsl obj = new StorageProductKcsl();
			obj.setHdsj(new Date());
			storageProductKcslMapper.updateByExampleSelective(obj, example);
		}
	}

}
